.. _whatsnew-0.2:

=========================
What's New in Astropy 0.2
=========================

See this page in the `Astropy v0.2 documentation`__.

__ http://docs.astropy.org/en/v0.2.5/whatsnew/0.2.html
